# SklearnModelConfig

::: factrainer.sklearn.SklearnModelConfig
    options:
        members:
            - learner
            - predictor
            - train_config
            - pred_config
            - create